[xiph-commits] r15299 - in trunk/cdparanoia: . interface

xiphmont at svn.xiph.org xiphmont at svn.xiph.org
Thu Sep 11 13:33:31 PDT 2008


Author: xiphmont
Date: 2008-09-11 13:33:30 -0700 (Thu, 11 Sep 2008)
New Revision: 15299

Modified:
   trunk/cdparanoia/Makefile.in
   trunk/cdparanoia/README
   trunk/cdparanoia/interface/scsi_interface.c
   trunk/cdparanoia/interface/test_interface.c
   trunk/cdparanoia/version.h
Log:
Move max transfer size back to 64kB
Update build and README
Bump version for test/release


Modified: trunk/cdparanoia/Makefile.in
===================================================================
--- trunk/cdparanoia/Makefile.in	2008-09-11 20:09:40 UTC (rev 15298)
+++ trunk/cdparanoia/Makefile.in	2008-09-11 20:33:30 UTC (rev 15299)
@@ -64,7 +64,7 @@
 
 install:
 	$(INSTALL) -d -m 0755 $(BINDIR)
-	$(INSTALL) -m 4755 -o root $(srcdir)/cdparanoia $(BINDIR)
+	$(INSTALL) -m 755 $(srcdir)/cdparanoia $(BINDIR)
 	$(INSTALL) -d -m 0755 $(MANDIR)
 	$(INSTALL) -d -m 0755 $(MANDIR)/man1
 	$(INSTALL) -m 0644 $(srcdir)/cdparanoia.1 $(MANDIR)/man1

Modified: trunk/cdparanoia/README
===================================================================
--- trunk/cdparanoia/README	2008-09-11 20:09:40 UTC (rev 15298)
+++ trunk/cdparanoia/README	2008-09-11 20:33:30 UTC (rev 15299)
@@ -1,5 +1,5 @@
-cdparanoia III release 10.0 README
-[May 12, 2008]
+cdparanoia III release 10.2 README
+[September 11, 2008]
 
 Monty <monty at xiph.org>
 
@@ -15,8 +15,8 @@
 COPYING
 =======
 
-cdparanoia (the command line tool) is released under the GPLv3.  The
-interface and paranoia libraries are covered by the LGPLv3.
+cdparanoia (the command line tool) is released under the GPLv2.  The
+interface and paranoia libraries are covered by the LGPLv2.1.
 
 Requirements
 ============
@@ -56,12 +56,15 @@
 	(/dev/sg?) files in /dev. Most distributions already have the 
 	/dev/sg? files. (kernels older than 2.6)
 
-3. A Linux 2.2.x, 2.3.x, 2.4.x, 2.5.x or 2.6.x kernel 
+3. A Linux 2.4.x, 2.5.x or 2.6.x kernel 
 
-/proc filesystem support is no longer needed, although you'll
-certainly want to have it for other packages.  Cdparanoia does not
-require threading, IPC or sound card support.
+Timing changes as of cdparanoia 10.2 likely mandate the use of a 2.4
+or later kernel (tested).  Older kernels may be missing the realtime
+clock infrastructure now needed for the beefed up cache paranoia added
+to 10.2.
 
+Cdparanoia does not require threading, IPC or sound card support.
+
 Compiling cdparanoia
 ==================
 

Modified: trunk/cdparanoia/interface/scsi_interface.c
===================================================================
--- trunk/cdparanoia/interface/test_interface.c	2008-09-11 20:09:40 UTC (rev 15298)
+++ trunk/cdparanoia/interface/test_interface.c	2008-09-11 20:33:30 UTC (rev 15299)
@@ -25,7 +25,7 @@
 
 #undef  CDDA_TEST_ALLJITTER
 #undef  CDDA_TEST_SOMEJITTER
-#undef CDDA_TEST_SEEKJITTER
+#undef  CDDA_TEST_SEEKJITTER
 
 static int test_readtoc (cdrom_drive *d){
   int tracks=0;

Modified: trunk/cdparanoia/version.h
===================================================================
--- trunk/cdparanoia/version.h	2008-09-11 20:09:40 UTC (rev 15298)
+++ trunk/cdparanoia/version.h	2008-09-11 20:33:30 UTC (rev 15299)
@@ -1,11 +1,11 @@
 /******************************************************************
  * CopyPolicy: GNU Public License 2 applies
  * 
- * cdda_paranoia generation III release 10.2pre
+ * cdda_paranoia generation III release 10.2
  * Copyright (C) 2008 Monty monty at xiph.org
  *
  ******************************************************************/
 
 
-#define VERSIONNUM "10.2pre"
-#define VERSION "cdparanoia III release " VERSIONNUM " (August 11, 2008)\n"
+#define VERSIONNUM "10.2"
+#define VERSION "cdparanoia III release " VERSIONNUM " (September 11, 2008)\n"



More information about the commits mailing list
--- trunk/cdparanoia/interface/scsi_interface.c	2008-09-11 20:09:40 UTC (rev 15298)
+++ trunk/cdparanoia/interface/scsi_interface.c	2008-09-11 20:33:30 UTC (rev 15299)
@@ -73,10 +73,10 @@
    * Updated: but we don't always get -ENOMEM.  Sometimes USB drives 
    * still fail the wrong way.  This needs some kernel-land investigation.
    */
   /* Bumping to 55 sector transfer max --Monty */
 
   if (!getenv("CDDA_IGNORE_BUFSIZE_LIMIT")) {
-    cur=((cur+CD_FRAMESIZE_RAW-1)/CD_FRAMESIZE_RAW>55?55*CD_FRAMESIZE_RAW:cur);
+    cur=(cur>1024*64?1024*64:cur);
   }else{
     cdmessage(d,"\tEnvironment variable CDDA_IGNORE_BUFSIZE_LIMIT set,\n"
 	      "\t\tforcing maximum possible sector size.  This can break\n"
@@ -73,10 +73,10 @@
    * still fail the wrong way.  This needs some kernel-land investigation.
    */
-  /* Bumping to 55 sector transfer max --Monty */
+  /* Bumping to 64kB  transfer max --Monty */
 
   if (!getenv("CDDA_IGNORE_BUFSIZE_LIMIT")) {

Modified: trunk/cdparanoia/interface/test_interface.c
===================================================================